Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(548)

Unified Diff: lib/compiler/implementation/ssa/codegen.dart

Issue 10911007: Rename Type to DartType to avoid conflicts with the class Type in the core library. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: lib/compiler/implementation/ssa/codegen.dart
diff --git a/lib/compiler/implementation/ssa/codegen.dart b/lib/compiler/implementation/ssa/codegen.dart
index b377e5f30833e5189f225db2f4204481bfeff93a..3ba454e0db790bd3d4eb5388d2a5b1a4077f27a0 100644
--- a/lib/compiler/implementation/ssa/codegen.dart
+++ b/lib/compiler/implementation/ssa/codegen.dart
@@ -1479,7 +1479,7 @@ class SsaCodeGenerator implements HVisitor, HBlockInformationVisitor {
// TODO(4434): For private members we need to use the untyped selector.
if (defaultSelector.name.isPrivate()) return defaultSelector;
HType receiverHType = types[node.inputs[0]];
- Type receiverType = receiverHType.computeType(compiler);
+ DartType receiverType = receiverHType.computeType(compiler);
if (receiverType !== null) {
return new TypedSelector(receiverType, defaultSelector);
} else {
@@ -1579,7 +1579,7 @@ class SsaCodeGenerator implements HVisitor, HBlockInformationVisitor {
use(node.receiver);
push(new js.PropertyAccess.field(pop(), name), node);
HType receiverHType = types[node.receiver];
- Type type = receiverHType.computeType(compiler);
+ DartType type = receiverHType.computeType(compiler);
if (type != null) {
world.registerFieldGetter(
node.element.name, node.element.getLibrary(), type);
@@ -1608,7 +1608,7 @@ class SsaCodeGenerator implements HVisitor, HBlockInformationVisitor {
node.value.guaranteedType);
}
String name = compiler.namer.getName(node.element);
- Type type = types[node.receiver].computeType(compiler);
+ DartType type = types[node.receiver].computeType(compiler);
if (type != null) {
if (!work.element.isGenerativeConstructorBody()) {
world.registerFieldSetter(
@@ -2230,7 +2230,7 @@ class SsaCodeGenerator implements HVisitor, HBlockInformationVisitor {
}
void visitIs(HIs node) {
- Type type = node.typeExpression;
+ DartType type = node.typeExpression;
Element element = type.element;
if (element.kind === ElementKind.TYPE_VARIABLE) {
compiler.unimplemented("visitIs for type variables", instruction: node);
@@ -2284,7 +2284,7 @@ class SsaCodeGenerator implements HVisitor, HBlockInformationVisitor {
if (node.hasTypeInfo()) {
InterfaceType interfaceType = type;
ClassElement cls = type.element;
- Link<Type> arguments = interfaceType.arguments;
+ Link<DartType> arguments = interfaceType.arguments;
js.Expression result = pop();
for (TypeVariableType typeVariable in cls.typeVariables) {
use(node.typeInfoCall);
@@ -2718,7 +2718,7 @@ class SsaUnoptimizedCodeGenerator extends SsaCodeGenerator {
bool visitSequenceInfo(HStatementSequenceInformation info) => false;
void visitTypeGuard(HTypeGuard node) {
// Do nothing. Type guards are only used in the optimized version.
kasperl 2012/08/30 14:11:27 Undo this edit.
}
void visitBailoutTarget(HBailoutTarget node) {
@@ -2718,7 +2718,7 @@ class SsaUnoptimizedCodeGenerator extends SsaCodeGenerator {
bool visitSequenceInfo(HStatementSequenceInformation info) => false;
void visitTypeGuard(HTypeGuard node) {
- // Do nothing. Type guards are only used in the optimized version.
+ // Do nothing. DartType guards are only used in the optimized version.
kasperl 2012/08/30 14:11:27 Undo this edit.
}

Powered by Google App Engine
This is Rietveld 408576698